quantizationtools.QSchema
=========================

.. abjad-lineage:: abjad.tools.quantizationtools.QSchema.QSchema.QSchema

.. autoclass:: abjad.tools.quantizationtools.QSchema.QSchema.QSchema
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.quantizationtools.QSchema.QSchema.QSchema.item_klass
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QSchema.QSchema.QSchema.items
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QSchema.QSchema.QSchema.search_tree
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QSchema.QSchema.QSchema.storage_format
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QSchema.QSchema.QSchema.target_item_klass
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QSchema.QSchema.QSchema.target_klass
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QSchema.QSchema.QSchema.tempo
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.quantizationtools.QSchema.QSchema.QSchema.__call__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QSchema.QSchema.QSchema.__eq__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QSchema.QSchema.QSchema.__ge__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QSchema.QSchema.QSchema.__getitem__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QSchema.QSchema.QSchema.__gt__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QSchema.QSchema.QSchema.__le__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QSchema.QSchema.QSchema.__lt__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QSchema.QSchema.QSchema.__ne__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QSchema.QSchema.QSchema.__repr__
   :noindex:
